<?php

namespace Blog;



session_start();

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Factory\AppFactory;
use Blog\DB\User;
use Blog\DB\Blog;
use Blog\View\Twig;

require __DIR__ . '/../vendor/autoload.php';

$twig = new Twig('../templates');

addNavbar();

$app = AppFactory::create();



function addNavbar()
{
    global $twig;

    $urls = [
        ["link" => "https://www.google.be", "name" => "Google"],
        ["link" => "https://www.facebook.com", "name" => "Facebook"],
        ["link" => "https://www.twiter.com", "name" => "Twitter"]
    ];
    $twig->addBlockVariable('navbar', ['urls' => $urls]);
}



function addFooter($response)
{
    $response->getBody()->write('<div>Privacy statement | Cookie Policy | Contact</div>');
    $response->getBody()->write("</body></html>");
    return;
}
function init()
{
    $art1 = ["slug" => "artikel-1", "title" => "Dit is titel 1", "content" => "Lorem ipsum 1"];
    $art2 = ["slug" => "artikel-2", "title" => "Dit is titel 2", "content" => "Lorem ipsum 2"];
    $art3 = ["slug" => "artikel-3", "title" => "Dit is titel 3", "content" => "Lorem ipsum 3"];
    $art4 = ["slug" => "artikel-4", "title" => "Dit is titel 4", "content" => "Lorem ipsum 4"];
    $_SESSION['blogs'] = [$art1, $art2, $art3, $art4];
}

$app->get('/', function (Request $request, Response $response, array $args) {
    if (!isset($_SESSION['blogs'])) {
        init();
    }

    $vars = [
        "key" => "value",
        'key2' => ["val1", "val2", "val3"],
        "key3" => ["x1" => "y1", "x2" => "y2"],
        "loggedIn" => isset($_SESSION['username']),
        "content" => "Dit is de main body met info"

    ];

    global $twig;
    $a =  $twig->render('index.html.twig', $vars);
    $response->getBody()->write($a);
    return $response;
});

$app->map(['GET', 'POST'], '/blog/create', function (Request $request, Response $response, array $args) {
    if (isset($_SESSION['username'])) {
        if ($request->getMethod() == 'GET') {
            addNavbar($response);
            if (isset($_SESSION['error'])) {
                $response->getBody()->write($_SESSION['error']);
                $response->getBody()->write('<hr/>');
                unset($_SESSION['error']);
            }

            // Opdracht : Toon reeds ingevoerde gegevens in geval van foutmelding
            $response->getBody()->write('<form action="/blog/create" method="POST">');
            $response->getBody()->write('<label for="slug">slug:</label>');
            $response->getBody()->write('<input type="text" name="slug"/><br/>');
            $response->getBody()->write('<label for="title">Titel:</label>');
            $response->getBody()->write('<input type="text" name="title"/><br/>');
            $response->getBody()->write('<label for="content">Inhoud:</label>');
            $response->getBody()->write('<textarea type="textarea" name="content"></textarea><br/>');
            $response->getBody()->write('<input type="submit"/>');
            addFooter($response);
        } else {
            $data = $request->getParsedBody();
            $blog = new Blog();

            $res = $blog->createBlog($data);
            if ($res) {
                return $response->withHeader('Location', '/')->withStatus(302);
            } else {
                $err = $blog->lastErrorMsg();
                $_SESSION['error'] = $err;
                return $response->withHeader('Location', '/blog/create')->withStatus(302);
            }
        }
    } else {
        addNavbar($response);
        $response->getBody()->write(('Please login'));
        addFooter($response);
    }
    return $response;
});

$app->get('/blog/{slug}', function (Request $request, Response $response, array $args) {

    addNavbar($response);
    foreach ($_SESSION['blogs'] as $art) {
        if ($art['slug'] == $args['slug']) {
            $response->getBody()->write("<h1>" . $art['title'] . "</h1>");
        }
    }

    addFooter($response);
    return $response;
});

$app->get('/logout', function (Request $request, Response $response, array $args) {
    unset($_SESSION['username']);
    addNavbar($response);
    $response->getBody()->write('Logged out');
    addFooter($response);
    return $response->withHeader('Location', '/')->withStatus(302);
});

$app->map(['GET', 'POST'], '/login', function (Request $request, Response $response, array $args) {

    if ($request->getMethod() == 'GET') {
        addNavbar($response);
        $response->getBody()->write('<form action="/login" method="POST">');
        $response->getBody()->write('<label for="username">Username:</label>');
        $response->getBody()->write('<input type="text" name="username"/><br/>');
        $response->getBody()->write('<label for="password">Password:</label>');
        $response->getBody()->write('<input type="password" name="password"/><br/>');
        $response->getBody()->write('<input type="submit"/>');
        addFooter($response);
    } else {
        $postdata = $request->getParsedBody();

        $user = new User();
        $logged_in = $user->checkUserPass($postdata['username'], $postdata['password']);
        if ($logged_in) {
            //if ($postdata['username'] == 'gebruiker' && $postdata['password'] == "abcd") {
            $_SESSION["username"] = $postdata['username'];
            addNavbar($response);
            $response->getBody()->write('Logged in');
            addFooter($response);
            return $response->withHeader('Location', '/')->withStatus(302);
        } else {
            $response->getBody()->write('Username and/or password incorrect');
        }
    }
    return $response;
});

$app->post('/postcomment', function (Request $request, Response $response, array $args) {
    $response->getBody()->write("Postcomment");
    return $response;
});



$app->run();
